@@ -25,28 +25,48 @@
 #include <config.h>
 #endif
 
-#include "libebackend/e-data-server-module.h"
-#include "libedata-book/e-book-backend-factory.h"
+#include <libedata-book/e-book-backend-factory.h>
 #include "e-book-backend-ews.h"
 
-E_BOOK_BACKEND_FACTORY_SIMPLE (ews, Ews, e_book_backend_ews_new)
+typedef EBookBackendFactory EBookBackendEwsFactory;
+typedef EBookBackendFactoryClass EBookBackendEwsFactoryClass;
 
-static GType  ews_types [1];
+/* Module Entry Points */
+void e_module_load (GTypeModule *type_module);
+void e_module_unload (GTypeModule *type_module);
 
-void
-eds_module_initialize (GTypeModule *module)
+/* Forward Declarations */
+GType e_book_backend_ews_factory_get_type (void);
+
+G_DEFINE_DYNAMIC_TYPE (
+	EBookBackendEwsFactory,
+	e_book_backend_ews_factory,
+	E_TYPE_BOOK_BACKEND_FACTORY)
+
+static void
+e_book_backend_ews_factory_class_init (EBookBackendFactoryClass *class)
 {
-	ews_types[0] = _ews_factory_get_type (module);
+	class->factory_name = "ews";
+	class->backend_type = E_TYPE_BOOK_BACKEND_EWS;
 }
 
-void
-eds_module_shutdown   (void)
+static void
+e_book_backend_ews_factory_class_finalize (EBookBackendFactoryClass *class)
 {
 }
 
-void
-eds_module_list_types (const GType **types, gint *num_types)
+static void
+e_book_backend_ews_factory_init (EBookBackendFactory *factory)
+{
+}
+
+G_MODULE_EXPORT void
+e_module_load (GTypeModule *type_module)
+{
+	e_book_backend_ews_factory_register_type (type_module);
+}
+
+G_MODULE_EXPORT void
+e_module_unload (GTypeModule *type_module)
 {
-	*types = ews_types;
-	*num_types = G_N_ELEMENTS (ews_types);
 }
