@@ -133,7 +133,7 @@ convert_error_to_edb_error (GError **perror)
 	if ((*perror)->domain == EWS_CONNECTION_ERROR) {
 		switch ((*perror)->code) {
 		case EWS_CONNECTION_ERROR_AUTHENTICATION_FAILED:
-			error = EDB_ERROR (AUTHENTICATION_FAILED);
+			error = EDB_ERROR_EX (AUTHENTICATION_FAILED, (*perror)->message);
 			break;
 		case EWS_CONNECTION_ERROR_CANCELLED:
 			break;
@@ -141,11 +141,11 @@ convert_error_to_edb_error (GError **perror)
 		case EWS_CONNECTION_ERROR_MANAGEDFOLDERNOTFOUND:
 		case EWS_CONNECTION_ERROR_PARENTFOLDERNOTFOUND:
 		case EWS_CONNECTION_ERROR_PUBLICFOLDERSERVERNOTFOUND:
-			error = EDB_ERROR (NO_SUCH_BOOK);
+			error = EDB_ERROR_EX (NO_SUCH_BOOK, (*perror)->message);
 			break;
 		case EWS_CONNECTION_ERROR_EVENTNOTFOUND:
 		case EWS_CONNECTION_ERROR_ITEMNOTFOUND:
-			error = EDB_ERROR (CONTACT_NOT_FOUND);
+			error = EDB_ERROR_EX (CONTACT_NOT_FOUND, (*perror)->message);
 			break;
 		}
 	}
@@ -2012,23 +2012,6 @@ ebews_get_vcards_list (GSList *new_items,
 	g_slist_free (new_items);
 }
 
-static void
-ews_mb_free (EwsMailbox *mb)
-{
-	if (mb) {
-		g_free (mb->name);
-		g_free (mb->email);
-
-		if (mb->item_id) {
-			g_free (mb->item_id->id);
-			g_free (mb->item_id->change_key);
-			g_free (mb->item_id);
-		}
-
-		g_free (mb);
-	}
-}
-
 static void
 ebews_store_distribution_list_items (EBookBackendEws *ebews,
                                      const EwsId *id,
@@ -2069,7 +2052,7 @@ ebews_store_distribution_list_items (EBookBackendEws *ebews,
 			e_vcard_attribute_add_value (attr, mb->email);
 
 		e_vcard_add_attribute (E_VCARD (contact), attr);
-		ews_mb_free (mb);
+		e_ews_mailbox_free (mb);
 	}
 
 	g_slist_free (members);
@@ -2117,7 +2100,7 @@ ebews_vcards_append_dl (const EwsId *id,
 			e_vcard_attribute_add_value (attr, mb->email);
 
 		e_vcard_add_attribute (E_VCARD (contact), attr);
-		ews_mb_free (mb);
+		e_ews_mailbox_free (mb);
 	}
 	vcard_string = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 	*vcards = g_slist_append (*vcards, g_strdup(vcard_string));
@@ -2303,6 +2286,9 @@ ebews_start_sync (gpointer data)
 
 	g_free (sync_state);
 
+	/* hide progress message when done */
+	e_book_backend_foreach_view (E_BOOK_BACKEND (ebews), book_view_notify_status, NULL);
+
 	if (error) {
 		g_warning ("Error Syncing Contacts: Folder %s Error: %s", priv->folder_id, error->message);
 		g_clear_error (&error);
@@ -2552,9 +2538,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 
 		e_data_book_view_notify_update (book_view, contact);
 
-		g_free (mb->email);
-		g_free (mb->name);
-		g_free (mb);
+		e_ews_mailbox_free (mb);
 		e_ews_free_resolve_contact (rc);
 		g_object_unref (contact);
 	}
