@@ -63,12 +63,12 @@ const gchar *vcard_str =
 static void
 quit_tests (void)
 {
-	
+
 	if (error != NULL) {
 		g_print ("Tests failed: %s - %s \n", op, error->message);
 		g_clear_error (&error);
 	}
-	
+
 	g_main_loop_quit (main_loop);
 }
 
@@ -80,20 +80,22 @@ add_contacts (EBookBackendSqliteDB *ebsdb)
 
 	g_print ("Adding contact \n");
 	op = "add contact";
-	
+
 	con = e_contact_new_from_vcard (vcard_str);
 	contacts = g_slist_append (contacts, con);
 	e_book_backend_sqlitedb_add_contacts (ebsdb, folderid, contacts, FALSE, &error);
-	
+
 	g_object_unref (con);
 }
 
 static void
-search_db (EBookBackendSqliteDB *ebsdb, const gchar *type, const gchar *sexp)
+search_db (EBookBackendSqliteDB *ebsdb,
+           const gchar *type,
+           const gchar *sexp)
 {
 	GSList *vcards;
 	EbSdbSearchData *s_data;
-	
+
 	g_print ("%s - query: %s \n", type, sexp);
 	op = type;
 	vcards = e_book_backend_sqlitedb_search (ebsdb, folderid, sexp, NULL, NULL, NULL, &error);
@@ -117,7 +119,7 @@ start_tests (gpointer data)
 
 	g_print ("Creating the sqlitedb \n");
 	op = "create sqlitedb";
-	ebsdb = e_book_backend_sqlitedb_new 
+	ebsdb = e_book_backend_sqlitedb_new
 					(cache_path, email, folderid, folder_name,
 					 store_vcard, &error);
 	if (error)
@@ -132,20 +134,20 @@ start_tests (gpointer data)
 	e_book_backend_sqlitedb_set_is_populated (ebsdb, folderid, TRUE, &error);
 	if (error)
 		goto exit;
-	
+
 	g_print ("Setting is_populated \n");
 	op = "set is_populated";
 	populated = e_book_backend_sqlitedb_get_is_populated (ebsdb, folderid, &error);
 	if (error)
 		goto exit;
 	g_print ("Populated: %d \n", populated);
-	
+
 	g_print ("Setting key value \n");
 	op = "set key/value";
 	e_book_backend_sqlitedb_set_key_value (ebsdb, folderid, "customkey", "stored", &error);
 	if (error)
 		goto exit;
-	
+
 	g_print ("Get Vcard string \n");
 	op = "get vcard string";
 	vcard_str = e_book_backend_sqlitedb_get_vcard_string (ebsdb, folderid, uid, NULL, NULL, &error);
@@ -171,7 +173,7 @@ start_tests (gpointer data)
 		if (error)
 			goto exit;
 	}
-	
+
 	g_print ("Delete contact \n");
 	op = "delete contact";
 	uids = g_slist_append (uids, (gchar *) uid);
@@ -183,15 +185,16 @@ start_tests (gpointer data)
 	g_print ("Delete addressbook \n");
 	op = "delete addressbook";
 	e_book_backend_sqlitedb_delete_addressbook (ebsdb, folderid, &error);
-	
+
 exit:
 	g_object_unref (ebsdb);
 	quit_tests ();
-	return FALSE;	
+	return FALSE;
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc,
+      gchar *argv[])
 {
 	g_type_init ();
 
