@@ -390,6 +390,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	const gchar *temp;
 	gboolean res;
 	gchar *mime_fname_new = NULL;
+	GError *local_error = NULL;
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 	ews_folder = (CamelEwsFolder *) folder;
@@ -443,11 +444,14 @@ camel_ews_folder_get_message (CamelFolder *folder,
 					  &items,
 					  (ESoapProgressFn) camel_operation_progress,
 					  (gpointer) cancellable,
-					  cancellable, error);
+					  cancellable, &local_error);
 	g_free (mime_dir);
 
-	if (!res)
+	if (!res || !items) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		goto exit;
+	}
 
 	/* The mime_content actually contains the *filename*, due to the
 	 * streaming hack in ESoapMessage */
@@ -471,12 +475,16 @@ camel_ews_folder_get_message (CamelFolder *folder,
 						  &items_req,
 						  (ESoapProgressFn) camel_operation_progress,
 						  (gpointer) cancellable,
-						  cancellable, error);
+						  cancellable, &local_error);
 		if (!res || (items_req && e_ews_item_get_item_type (items_req->data) == E_EWS_ITEM_TYPE_ERROR)) {
 			if (items_req) {
 				g_object_unref (items_req->data);
 				g_slist_free (items_req);
 			}
+			if (local_error) {
+				camel_ews_store_maybe_disconnect (ews_store, local_error);
+				g_propagate_error (error, local_error);
+			}
 			goto exit;
 		}
 		calendar_item_accept_id = e_ews_item_get_calendar_item_accept_id (items_req->data);
@@ -541,6 +549,7 @@ exit:
 
 	if (mime_fname_new)
 		g_free (mime_fname_new);
+	g_object_unref (cnc);
 
 	return message;
 }
@@ -774,15 +783,31 @@ ews_sync_mi_flags (CamelFolder *folder,
 {
 	CamelEwsStore *ews_store;
 	EEwsConnection *cnc;
+	GError *local_error = NULL;
+	gboolean res;
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
+
+	if (!camel_ews_store_connected (ews_store, error)) {
+		return FALSE;
+	}
+
 	cnc = camel_ews_store_get_connection (ews_store);
 
-	return e_ews_connection_update_items (cnc, EWS_PRIORITY_LOW,
+	res = e_ews_connection_update_items (cnc, EWS_PRIORITY_LOW,
 					      "AlwaysOverwrite", "SaveOnly",
 					      NULL, NULL,
 					      msg_update_flags, mi_list, NULL,
-					      cancellable, error);
+					      cancellable, &local_error);
+
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
+	}
+
+	g_object_unref (cnc);
+
+	return res;
 }
 
 static gboolean
@@ -829,12 +854,14 @@ ews_move_to_junk_folder (CamelFolder *folder,
 	}
 
 	ews_store = CAMEL_EWS_STORE (camel_folder_get_parent_store (folder));
-	cnc = camel_ews_store_get_connection (ews_store);
 
 	parent_store = camel_folder_get_parent_store (folder);
 	ews_folder = CAMEL_EWS_FOLDER (folder);
 	ews_store = CAMEL_EWS_STORE (parent_store);
 
+	if (!camel_ews_store_connected (ews_store, error))
+		return FALSE;
+
 	cnc = camel_ews_store_get_connection (ews_store);
 
 	if (junk_uids) {
@@ -879,17 +906,23 @@ ews_move_to_junk_folder (CamelFolder *folder,
 				camel_folder_summary_unlock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
 			}
 
-			if (camel_folder_change_info_changed (changes))
+			if (camel_folder_change_info_changed (changes)) {
+				camel_folder_summary_touch (folder->summary);
 				camel_folder_changed (folder, changes);
+			}
 			camel_folder_change_info_free (changes);
 		}
 
-		if (local_error)
+		if (local_error) {
+			camel_ews_store_maybe_disconnect (ews_store, local_error);
 			g_propagate_error (error, local_error);
+		}
 
 		g_slist_free_full (junk_uids, (GDestroyNotify) camel_pstring_free);
 	}
 
+	g_object_unref (cnc);
+
 	return status;
 }
 
@@ -934,7 +967,8 @@ ews_synchronize_sync (CamelFolder *folder,
 
 		/* Exchange doesn't seem to have a sane representation
 		 * for most flags — not even replied/forwarded. */
-		if (flags_changed & (CAMEL_MESSAGE_SEEN | CAMEL_MESSAGE_ANSWERED | CAMEL_MESSAGE_FORWARDED | CAMEL_MESSAGE_FLAGGED)) {
+		if ((flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0 &&
+		    (flags_changed & (CAMEL_MESSAGE_SEEN | CAMEL_MESSAGE_ANSWERED | CAMEL_MESSAGE_FORWARDED | CAMEL_MESSAGE_FLAGGED)) != 0) {
 			mi_list = g_slist_append (mi_list, mi);
 			mi_list_len++;
 
@@ -948,7 +982,7 @@ ews_synchronize_sync (CamelFolder *folder,
 		} else if (flags_set & CAMEL_MESSAGE_JUNK) {
 			junk_uids = g_slist_prepend (junk_uids, (gpointer) camel_pstring_strdup (uids->pdata[i]));
 			camel_message_info_free (mi);
-		} else if (mi->info.dirty || (flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0) {
+		} else if ((flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0) {
 			/* OK, the change must have been the labels */
 			mi_list = g_slist_append (mi_list, mi);
 			mi_list_len++;
@@ -1089,9 +1123,13 @@ sync_updated_items (CamelEwsFolder *ews_folder,
                     GCancellable *cancellable,
                     GError **error)
 {
+	CamelEwsStore *ews_store;
 	CamelFolder *folder = (CamelFolder *) ews_folder;
 	GSList *items = NULL, *l;
 	GSList *generic_item_ids = NULL, *msg_ids = NULL;
+	GError *local_error = NULL;
+
+	ews_store = CAMEL_EWS_STORE (camel_folder_get_parent_store (folder));
 
 	for (l = updated_items; l != NULL; l = g_slist_next (l)) {
 		EEwsItem *item = (EEwsItem *) l->data;
@@ -1125,24 +1163,32 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 
 	if (msg_ids)
 		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			(cnc, EWS_PRIORITY_MEDIUM,
 			 msg_ids, "IdOnly", SUMMARY_MESSAGE_FLAGS,
 			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+			 cancellable, &local_error);
 
 	camel_ews_utils_sync_updated_items (ews_folder, items);
 	items = NULL;
-	if (*error)
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		goto exit;
+	}
 
 	if (generic_item_ids)
 		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			(cnc, EWS_PRIORITY_MEDIUM,
 			 generic_item_ids, "IdOnly", SUMMARY_ITEM_FLAGS,
 			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+			 cancellable, &local_error);
 	camel_ews_utils_sync_updated_items (ews_folder, items);
 
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
+	}
+
 exit:
 	if (msg_ids) {
 		g_slist_foreach (msg_ids, (GFunc) g_free, NULL);
@@ -1162,8 +1208,12 @@ sync_created_items (CamelEwsFolder *ews_folder,
                     GCancellable *cancellable,
                     GError **error)
 {
+	CamelEwsStore *ews_store;
 	GSList *items = NULL, *l;
 	GSList *generic_item_ids = NULL, *msg_ids = NULL, *post_item_ids = NULL;
+	GError *local_error = NULL;
+
+	ews_store = CAMEL_EWS_STORE (camel_folder_get_parent_store (CAMEL_FOLDER (ews_folder)));
 
 	for (l = created_items; l != NULL; l = g_slist_next (l)) {
 		EEwsItem *item = (EEwsItem *) l->data;
@@ -1196,39 +1246,49 @@ sync_created_items (CamelEwsFolder *ews_folder,
 
 	if (msg_ids)
 		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			(cnc, EWS_PRIORITY_MEDIUM,
 			 msg_ids, "IdOnly", SUMMARY_MESSAGE_PROPS,
 			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+			 cancellable, &local_error);
 
-	if (*error)
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		goto exit;
+	}
 
-	camel_ews_utils_sync_created_items (ews_folder, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
 	items = NULL;
 
 	if (post_item_ids)
 		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			(cnc, EWS_PRIORITY_MEDIUM,
 			 post_item_ids, "IdOnly", SUMMARY_POSTITEM_PROPS,
 			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+			 cancellable, &local_error);
 
-	if (*error)
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		goto exit;
+	}
 
-	camel_ews_utils_sync_created_items (ews_folder, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
 	items = NULL;
 
 	if (generic_item_ids)
 		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			(cnc, EWS_PRIORITY_MEDIUM,
 			 generic_item_ids, "IdOnly", SUMMARY_ITEM_PROPS,
 			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+			 cancellable, &local_error);
 
-	camel_ews_utils_sync_created_items (ews_folder, items);
+	camel_ews_utils_sync_created_items (ews_folder, cnc, items);
 
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
+	}
 exit:
 	if (msg_ids) {
 		g_slist_foreach (msg_ids, (GFunc) g_free, NULL);
@@ -1259,7 +1319,7 @@ ews_refresh_info_sync (CamelFolder *folder,
 	gchar *id;
 	gchar *sync_state;
 	gboolean includes_last_item = FALSE;
-	GError *rerror = NULL;
+	GError *local_error = NULL;
 
 	full_name = camel_folder_get_full_name (folder);
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
@@ -1281,6 +1341,10 @@ ews_refresh_info_sync (CamelFolder *folder,
 	g_mutex_unlock (priv->state_lock);
 
 	cnc = camel_ews_store_get_connection (ews_store);
+	g_return_val_if_fail (cnc != NULL, FALSE);
+
+	camel_folder_summary_prepare_fetch_all (folder->summary, NULL);
+
 	id = camel_ews_store_summary_get_folder_id_from_name
 						(ews_store->summary,
 						 full_name);
@@ -1304,18 +1368,20 @@ ews_refresh_info_sync (CamelFolder *folder,
 							 "IdOnly", NULL,
 							 EWS_MAX_FETCH_COUNT, &includes_last_item,
 							 &items_created, &items_updated,
-							 &items_deleted, cancellable, &rerror);
+							 &items_deleted, cancellable, &local_error);
 
-		if (rerror)
+		if (local_error) {
+			camel_ews_store_maybe_disconnect (ews_store, local_error);
 			break;
+		}
 
 		if (items_deleted)
 			camel_ews_utils_sync_deleted_items (ews_folder, items_deleted);
 
 		if (items_created)
-			sync_created_items (ews_folder, cnc, items_created, cancellable, &rerror);
+			sync_created_items (ews_folder, cnc, items_created, cancellable, &local_error);
 
-		if (rerror) {
+		if (local_error) {
 			if (items_updated) {
 				g_slist_foreach (items_updated, (GFunc) g_object_unref, NULL);
 				g_slist_free (items_updated);
@@ -1325,9 +1391,9 @@ ews_refresh_info_sync (CamelFolder *folder,
 		}
 
 		if (items_updated)
-			sync_updated_items (ews_folder, cnc, items_updated, cancellable, &rerror);
+			sync_updated_items (ews_folder, cnc, items_updated, cancellable, &local_error);
 
-		if (rerror)
+		if (local_error)
 			break;
 
 		total = camel_folder_summary_count (folder->summary);
@@ -1341,12 +1407,12 @@ ews_refresh_info_sync (CamelFolder *folder,
 		((CamelEwsSummary *) folder->summary)->sync_state = sync_state;
 
 		camel_folder_summary_touch (folder->summary);
-		camel_folder_summary_save_to_db (folder->summary, NULL);
+	} while (!local_error && !includes_last_item);
 
-	} while (!rerror && !includes_last_item);
+	camel_folder_summary_save_to_db (folder->summary, NULL);
 
-	if (rerror)
-		g_propagate_error (error, rerror);
+	if (local_error)
+		g_propagate_error (error, local_error);
 
 	g_mutex_lock (priv->state_lock);
 	priv->refreshing = FALSE;
@@ -1356,7 +1422,7 @@ ews_refresh_info_sync (CamelFolder *folder,
 	g_object_unref (cnc);
 	g_free (id);
 
-	return !rerror;
+	return !local_error;
 }
 
 static gboolean
@@ -1373,6 +1439,7 @@ ews_append_message_sync (CamelFolder *folder,
 	CamelAddress *from;
 	CamelEwsStore *ews_store;
 	EEwsConnection *cnc;
+	GError *local_error = NULL;
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 
@@ -1384,6 +1451,10 @@ ews_append_message_sync (CamelFolder *folder,
 
 	from = CAMEL_ADDRESS (camel_mime_message_get_from (message));
 
+	if (!camel_ews_store_connected (ews_store, error)) {
+		return FALSE;
+	}
+
 	cnc = camel_ews_store_get_connection (ews_store);
 
 	if (!cnc) {
@@ -1396,7 +1467,9 @@ ews_append_message_sync (CamelFolder *folder,
 						  message,
 						  camel_message_info_flags (info),
 						  from, &itemid, &changekey,
-						  cancellable, error)) {
+						  cancellable, &local_error)) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		g_free (folder_id);
 		g_object_unref (cnc);
 		return FALSE;
@@ -1431,7 +1504,7 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	CamelFolderChangeInfo *changes = NULL;
 	const gchar *dst_full_name;
 	gchar *dst_id;
-	GError *rerror = NULL;
+	GError *local_error = NULL;
 	GSList *ids = NULL, *ret_items = NULL;
 	gint i = 0;
 
@@ -1454,7 +1527,7 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	if (e_ews_connection_move_items	(cnc, EWS_PRIORITY_MEDIUM,
 					 dst_id, !delete_originals,
 					 ids, &ret_items,
-					 cancellable, &rerror)) {
+					 cancellable, &local_error)) {
 		camel_service_unlock (CAMEL_SERVICE (dst_ews_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
 
 		if (delete_originals) {
@@ -1463,7 +1536,10 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 				camel_folder_summary_remove_uid (source->summary, uids->pdata[i]);
 				camel_folder_change_info_remove_uid (changes, uids->pdata[i]);
 			}
-			camel_folder_changed (source, changes);
+			if (camel_folder_change_info_changed (changes)) {
+				camel_folder_summary_touch (source->summary);
+				camel_folder_changed (source, changes);
+			}
 			camel_folder_change_info_free (changes);
 		}
 
@@ -1475,14 +1551,16 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	}
 	g_free (dst_id);
 
-	if (rerror)
-		g_propagate_error (error, rerror);
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (dst_ews_store, local_error);
+		g_propagate_error (error, local_error);
+	}
 
 	g_object_unref (cnc);
 	g_slist_free (ids);
 	g_slist_free_full (ret_items, g_object_unref);
 
-	return !rerror;
+	return !local_error;
 }
 
 static gboolean
@@ -1505,26 +1583,30 @@ ews_delete_messages (CamelFolder *folder,
 	ews_store = CAMEL_EWS_STORE (parent_store);
 	deleted_head = deleted_items;
 
+	if (!camel_ews_store_connected (ews_store, error)) {
+		return FALSE;
+	}
+
 	cnc = camel_ews_store_get_connection (ews_store);
 	changes = camel_folder_change_info_new ();
 
 	if (deleted_items) {
-		GError *rerror = NULL;
+		GError *local_error = NULL;
 		EwsDeleteType delete_type;
 
 		delete_type = expunge ? EWS_HARD_DELETE : EWS_MOVE_TO_DELETED_ITEMS;
 
 		camel_service_lock (CAMEL_SERVICE (ews_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
 		status = e_ews_connection_delete_items (cnc, EWS_PRIORITY_MEDIUM, deleted_items, delete_type,
-							EWS_SEND_TO_NONE, FALSE, cancellable, &rerror);
+							EWS_SEND_TO_NONE, FALSE, cancellable, &local_error);
 		camel_service_unlock (CAMEL_SERVICE (ews_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
 
-		if (!status && rerror->code == EWS_CONNECTION_ERROR_ITEMNOTFOUND) {
+		if (!status && local_error->code == EWS_CONNECTION_ERROR_ITEMNOTFOUND) {
 			/* If delete failed due to the item not found, ignore the error,
 			 * trigger folder info refresh and then go on to clear the
 			 * cache of the deleted items anyway. */
-			g_clear_error (&rerror);
-			status = ews_refresh_info_sync (folder, cancellable, &rerror);
+			g_clear_error (&local_error);
+			status = ews_refresh_info_sync (folder, cancellable, &local_error);
 		}
 
 		if (status) {
@@ -1539,16 +1621,22 @@ ews_delete_messages (CamelFolder *folder,
 			}
 		}
 
-		if (rerror)
-			g_propagate_error (error, rerror);
+		if (local_error) {
+			camel_ews_store_maybe_disconnect (ews_store, local_error);
+			g_propagate_error (error, local_error);
+		}
 
-		camel_folder_changed (folder, changes);
+		if (camel_folder_change_info_changed (changes)) {
+			camel_folder_summary_touch (folder->summary);
+			camel_folder_changed (folder, changes);
+		}
 
 		g_slist_foreach (deleted_head, (GFunc) camel_pstring_free, NULL);
 		g_slist_free (deleted_head);
 	}
 
 	camel_folder_change_info_free (changes);
+	g_object_unref (cnc);
 
 	return status;
 }
