@@ -92,10 +92,6 @@ gboolean
 void	camel_ews_summary_add_message	(CamelFolderSummary *summary,
 					 const gchar *uid,
 					 CamelMimeMessage *message);
-void	camel_ews_summary_add_message_info
-					(CamelFolderSummary *summary,
-					 guint32 server_flags,
-					 CamelMessageInfo *info);
 void	ews_summary_clear		(CamelFolderSummary *summary,
 					 gboolean uncache);
 
