@@ -668,7 +668,11 @@ camel_ews_utils_sync_deleted_items (CamelEwsFolder *ews_folder,
 	camel_db_delete_uids (((CamelStore *) ews_store)->cdb_w, full_name, items_deleted_list, NULL);
 	g_list_free (items_deleted_list);
 
-	camel_folder_changed ((CamelFolder *) ews_folder, ci);
+	if (camel_folder_change_info_changed (ci)) {
+		camel_folder_summary_touch (folder->summary);
+		camel_folder_summary_save_to_db (folder->summary, NULL);
+		camel_folder_changed (folder, ci);
+	}
 	camel_folder_change_info_free (ci);
 
 	g_slist_foreach (items_deleted, (GFunc) g_free, NULL);
@@ -793,38 +797,48 @@ ews_utils_get_server_flags (EEwsItem *item)
 }
 
 static const gchar *
-form_email_string_from_mb (const EwsMailbox *mb)
+form_email_string_from_mb (EEwsConnection *cnc,
+			   const EwsMailbox *mb,
+			   GCancellable *cancellable)
 {
-	const gchar *ret = NULL;
-
 	if (mb) {
 		GString *str;
+		gchar *email = NULL;
+
+		if (g_strcmp0 (mb->mb_type, "EX") == 0) {
+			e_ews_connection_ex_to_smtp_sync (
+				cnc, EWS_PRIORITY_MEDIUM,
+				mb->name, mb->email, &email,
+				cancellable, NULL);
+
+			/* do not scare users with EX addresses */
+			if (!email)
+				email = g_strdup ("");
+		}
 
 		str = g_string_new ("");
 		if (mb->name && mb->name[0]) {
-			str = g_string_append (str, mb->name);
-			str = g_string_append (str, " ");
-		} else {
-			str = g_string_append (str, mb->email);
-			str = g_string_append (str, " ");
+			g_string_append (str, mb->name);
+			g_string_append (str, " ");
 		}
 
-		if (mb->email) {
+		if (mb->email || email) {
 			g_string_append (str, "<");
-			str = g_string_append (str, mb->email);
+			g_string_append (str, email ? email : mb->email);
 			g_string_append (str, ">");
 		}
 
-		ret = camel_pstring_add (str->str, TRUE);
-		g_string_free (str, FALSE);
+		g_free (email);
 
-		return ret;
+		return camel_pstring_add (g_string_free (str, FALSE), TRUE);
 	} else
 	       return camel_pstring_strdup ("");
 }
 
 static const gchar *
-form_recipient_list (const GSList *recipients)
+form_recipient_list (EEwsConnection *cnc,
+		     const GSList *recipients,
+		     GCancellable *cancellable)
 {
 	const GSList *l;
 	GString *str = NULL;
@@ -835,7 +849,7 @@ form_recipient_list (const GSList *recipients)
 
 	for (l = recipients; l != NULL; l = g_slist_next (l)) {
 		EwsMailbox *mb = (EwsMailbox *) l->data;
-		const gchar *mb_str = form_email_string_from_mb (mb);
+		const gchar *mb_str = form_email_string_from_mb (cnc, mb, cancellable);
 
 		if (!str)
 			str = g_string_new ("");
@@ -966,14 +980,18 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 		g_object_unref (item);
 	}
 
-	camel_folder_summary_save_to_db (folder->summary, NULL);
-	camel_folder_changed ((CamelFolder *) ews_folder, ci);
+	if (camel_folder_change_info_changed (ci)) {
+		camel_folder_summary_touch (folder->summary);
+		camel_folder_summary_save_to_db (folder->summary, NULL);
+		camel_folder_changed ((CamelFolder *) ews_folder, ci);
+	}
 	camel_folder_change_info_free (ci);
 	g_slist_free (items_updated);
 }
 
 void
 camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
+				    EEwsConnection *cnc,
                                     GSList *items_created)
 {
 	CamelFolder *folder;
@@ -1037,13 +1055,15 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		mi->info.date_received = e_ews_item_get_date_received (item);
 
 		from = e_ews_item_get_from (item);
-		mi->info.from = form_email_string_from_mb (from);
+		if (!from)
+			from = e_ews_item_get_sender (item);
+		mi->info.from = form_email_string_from_mb (cnc, from, NULL);
 
 		to = e_ews_item_get_to_recipients (item);
-		mi->info.to = form_recipient_list (to);
+		mi->info.to = form_recipient_list (cnc, to, NULL);
 
 		cc = e_ews_item_get_cc_recipients (item);
-		mi->info.cc = form_recipient_list (cc);
+		mi->info.cc = form_recipient_list (cnc, cc, NULL);
 
 		e_ews_item_has_attachments (item, &has_attachments);
 		if (has_attachments)
@@ -1053,16 +1073,29 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		server_flags = ews_utils_get_server_flags (item);
 		ews_utils_merge_server_user_flags (item, mi);
 
-		camel_ews_summary_add_message_info (folder->summary, server_flags,
-						    (CamelMessageInfo *) mi);
+		mi->info.flags |= server_flags;
+		mi->server_flags = server_flags;
+
+		camel_folder_summary_add (folder->summary, (CamelMessageInfo *) mi);
+
+		/* camel_folder_summary_add() sets folder_flagged flag
+		   on the message info, but this is a fresh item downloaded
+		   from the server, thus unset it, to avoid resync up to the server
+		   on folder leave/store
+		*/
+		mi->info.flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
+
 		camel_folder_change_info_add_uid (ci, id->id);
 		camel_folder_change_info_recent_uid (ci, id->id);
 
 		g_object_unref (item);
 	}
 
-	camel_folder_summary_save_to_db (folder->summary, NULL);
-	camel_folder_changed ((CamelFolder *) ews_folder, ci);
+	if (camel_folder_change_info_changed (ci)) {
+		camel_folder_summary_touch (folder->summary);
+		camel_folder_summary_save_to_db (folder->summary, NULL);
+		camel_folder_changed ((CamelFolder *) ews_folder, ci);
+	}
 	camel_folder_change_info_free (ci);
 	g_slist_free (items_created);
 }
