@@ -187,6 +187,9 @@ EEwsConnection *e_ews_connection_new		(const gchar *uri,
 						 GCallback authenticate_cb,
 						 gpointer authenticate_ctx,
 						 GError **error);
+void		e_ews_connection_forget_password
+						(EEwsConnection *cnc);
+
 EEwsConnection *e_ews_connection_find		(const gchar *uri,
 						 const gchar *username);
 void		e_ews_connection_authenticate	(EEwsConnection *cnc,
@@ -482,6 +485,15 @@ gboolean	e_ews_connection_resolve_names	(EEwsConnection *cnc,
 						 gboolean *includes_last_item,
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_ews_connection_ex_to_smtp_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *name,
+						 const gchar *ex_address,
+						 gchar **smtp_address,
+						 GCancellable *cancellable,
+						 GError **error);
+
 /* Expand distribution lists */
 void		e_ews_connection_expand_dl_start
 						(EEwsConnection *cnc,
