@@ -56,7 +56,7 @@
 	e_soap_message_start_element (msg, "Exists", NULL, NULL); \
 	e_ews_message_write_string_parameter_with_attribute (msg, "FieldURI", NULL, NULL, "FieldURI", uri);\
 	e_soap_message_end_element (msg);
-	
+
 #define WRITE_GREATER_THAN_OR_EQUAL_TO_MESSAGE(msg, uri, val) \
 	e_soap_message_start_element (msg, "IsGreaterThanOrEqualTo", NULL, NULL); \
 	e_ews_message_write_string_parameter_with_attribute (msg, "FieldURI", NULL, NULL, "FieldURI", uri); \
@@ -97,7 +97,6 @@
 	e_soap_message_end_element (msg); \
 	e_soap_message_end_element (msg);
 
-
 typedef enum {
 	MATCH_CONTAINS,
 	MATCH_IS,
@@ -204,10 +203,11 @@ struct EmailIndex {
 };
 
 static ESExpResult *
-e_ews_implement_contact_contains ( ESExp *f,
-          				gint argc,
-					ESExpResult **argv,
-					gpointer data, match_type type)
+e_ews_implement_contact_contains (ESExp *f,
+                                  gint argc,
+                                  ESExpResult **argv,
+                                  gpointer data,
+                                  match_type type)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -219,7 +219,7 @@ e_ews_implement_contact_contains ( ESExp *f,
 		field = argv[0]->value.string;
 
 		if (argv[1]->type == ESEXP_RES_STRING && argv[1]->value.string != NULL) {
-			gchar *mode=NULL;
+			gchar *mode = NULL;
 
 			if (type == MATCH_CONTAINS || type == MATCH_ENDS_WITH)
 				mode = g_strdup ("Substring");
@@ -289,12 +289,12 @@ e_ews_implement_contact_contains ( ESExp *f,
 	return r;
 }
 
-
 static ESExpResult *
 e_ews_func_and_or_not (ESExp *f,
-			gint argc,
-			ESExpTerm **argv,
-			gpointer data, match_type type)
+                       gint argc,
+                       ESExpTerm **argv,
+                       gpointer data,
+                       match_type type)
 {
 	ESExpResult *r, *r1;
 	ESoapMessage *msg;
@@ -314,7 +314,7 @@ e_ews_func_and_or_not (ESExp *f,
 	} else if (type == MATCH_OR) {
 		if (argc >= 2)
 			e_soap_message_start_element (msg, "Or", NULL, NULL);
-	
+
 	} else if (type == MATCH_NOT)
 		e_soap_message_start_element (msg, "Not", NULL, NULL);
 
@@ -334,9 +334,9 @@ result:
 
 static ESExpResult *
 calendar_func_contains (ESExp *f,
-            		gint argc,
-			ESExpResult **argv,
-			gpointer data)
+                        gint argc,
+                        ESExpResult **argv,
+                        gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -418,9 +418,9 @@ calendar_func_contains (ESExp *f,
 
 static ESExpResult *
 calendar_func_has_categories (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                              gint argc,
+                              ESExpResult **argv,
+                              gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -441,15 +441,15 @@ calendar_func_has_categories (ESExp *f,
 
 static ESExpResult *
 calendar_func_has_attachment (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                              gint argc,
+                              ESExpResult **argv,
+                              gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
 
 	msg = (ESoapMessage *) data;
-	
+
 	if (argc == 0) {
 		WRITE_EXISTS_MESSAGE (msg, "item:HasAttachments");
 	}
@@ -461,9 +461,9 @@ calendar_func_has_attachment (ESExp *f,
 
 static ESExpResult *
 calendar_func_has_recurrence (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                              gint argc,
+                              ESExpResult **argv,
+                              gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -492,9 +492,9 @@ e_ews_make_timestamp (time_t when)
 
 static ESExpResult *
 calendar_func_occur_in_time_range (ESExp *f,
-               				gint argc,
-              				ESExpResult **argv,
-            				gpointer data)
+                                   gint argc,
+                                   ESExpResult **argv,
+                                   gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -529,9 +529,9 @@ calendar_func_occur_in_time_range (ESExp *f,
 
 static ESExpResult *
 calendar_func_occurrences_count (ESExp *f,
-				 gint argc,
-				 ESExpResult **argv,
-				 gpointer data)
+                                 gint argc,
+                                 ESExpResult **argv,
+                                 gpointer data)
 {
 	ESExpResult *r;
 
@@ -543,9 +543,9 @@ calendar_func_occurrences_count (ESExp *f,
 
 static ESExpResult *
 message_func_body_contains (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                            gint argc,
+                            ESExpResult **argv,
+                            gpointer data)
 
 {
 	ESExpResult *r;
@@ -567,9 +567,10 @@ message_func_body_contains (ESExp *f,
 
 static ESExpResult *
 common_message_func_header_contains (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data, match_type type)
+                                     gint argc,
+                                     ESExpResult **argv,
+                                     gpointer data,
+                                     match_type type)
 
 {
 	ESExpResult *r;
@@ -590,7 +591,7 @@ common_message_func_header_contains (ESExp *f,
 	if (argv[0]->type == ESEXP_RES_STRING) {
 		gchar *headername;
 		headername = argv[0]->value.string;
-		
+
 		if (argv[1]->type == ESEXP_RES_STRING) {
 			gchar *value;
 			value = argv[1]->value.string;
@@ -616,9 +617,9 @@ common_message_func_header_contains (ESExp *f,
 
 static ESExpResult *
 message_func_header_exists (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                            gint argc,
+                            ESExpResult **argv,
+                            gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -628,7 +629,7 @@ message_func_header_exists (ESExp *f,
 	if (argv[0]->type == ESEXP_RES_STRING) {
 		gchar *headername;
 		headername = argv[0]->value.string;
-		
+
 		if (!g_ascii_strcasecmp(headername, "subject")) {
 			WRITE_EXISTS_MESSAGE (msg, "item:Subject");
 		} else if (!g_ascii_strcasecmp(headername, "from")) {
@@ -649,9 +650,9 @@ message_func_header_exists (ESExp *f,
 
 static ESExpResult *
 message_func_system_flag (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                          gint argc,
+                          ESExpResult **argv,
+                          gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -678,9 +679,9 @@ message_func_system_flag (ESExp *f,
 
 static ESExpResult *
 message_func_sent_date (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                        gint argc,
+                        ESExpResult **argv,
+                        gpointer data)
 {
 	ESExpResult *r;
 
@@ -692,9 +693,9 @@ message_func_sent_date (ESExp *f,
 
 static ESExpResult *
 message_func_received_date (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                            gint argc,
+                            ESExpResult **argv,
+                            gpointer data)
 {
 	ESExpResult *r;
 
@@ -706,9 +707,9 @@ message_func_received_date (ESExp *f,
 
 static ESExpResult *
 message_func_current_date (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                           gint argc,
+                           ESExpResult **argv,
+                           gpointer data)
 {
 	ESExpResult *r;
 
@@ -719,13 +720,12 @@ message_func_current_date (ESExp *f,
 
 static ESExpResult *
 message_func_relative_months (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                              gint argc,
+                              ESExpResult **argv,
+                              gpointer data)
 {
 	ESExpResult *r;
 
-
 	if (argc != 1 || argv[0]->type != ESEXP_RES_INT) {
 		r = e_sexp_result_new (f, ESEXP_RES_BOOL);
 		r->value.boolean = FALSE;
@@ -739,10 +739,10 @@ message_func_relative_months (ESExp *f,
 }
 
 static ESExpResult *
-message_func_get_size  (ESExp *f,
-			gint argc,
-			ESExpResult **argv,
-			gpointer data)
+message_func_get_size (ESExp *f,
+                       gint argc,
+                       ESExpResult **argv,
+                       gpointer data)
 {
 	ESExpResult *r;
 
@@ -754,9 +754,9 @@ message_func_get_size  (ESExp *f,
 
 static ESExpResult *
 func_eq (ESExp *f,
-		gint argc,
-		ESExpResult **argv,
-		gpointer data)
+         gint argc,
+         ESExpResult **argv,
+         gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -795,9 +795,9 @@ func_eq (ESExp *f,
 
 static ESExpResult *
 func_gt (ESExp *f,
-		gint argc,
-		ESExpResult **argv,
-		gpointer data)
+         gint argc,
+         ESExpResult **argv,
+         gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -853,9 +853,9 @@ func_gt (ESExp *f,
 
 static ESExpResult *
 func_lt (ESExp *f,
-		gint argc,
-		ESExpResult **argv,
-		gpointer data)
+         gint argc,
+         ESExpResult **argv,
+         gpointer data)
 {
 	ESExpResult *r;
 	ESoapMessage *msg;
@@ -911,9 +911,9 @@ func_lt (ESExp *f,
 
 static ESExpResult *
 message_func_match_all (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                        gint argc,
+                        ESExpResult **argv,
+                        gpointer data)
 {
 	ESExpResult *r;
 
@@ -924,99 +924,99 @@ message_func_match_all (ESExp *f,
 
 static ESExpResult *
 message_func_header_contains (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                              gint argc,
+                              ESExpResult **argv,
+                              gpointer data)
 {
 	return common_message_func_header_contains (f, argc, argv, data, MATCH_CONTAINS);
 }
 
 static ESExpResult *
-message_func_header_matches  (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+message_func_header_matches (ESExp *f,
+                             gint argc,
+                             ESExpResult **argv,
+                             gpointer data)
 {
 	return common_message_func_header_contains (f, argc, argv, data, MATCH_IS);
 }
 
 static ESExpResult *
-message_func_header_starts_with  (ESExp *f,
-					gint argc,
-					ESExpResult **argv,
-					gpointer data)
+message_func_header_starts_with (ESExp *f,
+                                 gint argc,
+                                 ESExpResult **argv,
+                                 gpointer data)
 {
 	return common_message_func_header_contains (f, argc, argv, data, MATCH_BEGINS_WITH);
 }
 
-static ESExpResult *  
+static ESExpResult *
 message_func_header_ends_with (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                               gint argc,
+                               ESExpResult **argv,
+                               gpointer data)
 {
 	return common_message_func_header_contains (f, argc, argv, data, MATCH_ENDS_WITH);
 }
 
 static ESExpResult *
 contact_func_contains (ESExp *f,
-			gint argc,
-			ESExpResult **argv,
-			gpointer data)
+                       gint argc,
+                       ESExpResult **argv,
+                       gpointer data)
 {
 	return e_ews_implement_contact_contains (f, argc, argv, data, MATCH_CONTAINS);
 }
 
 static ESExpResult *
 contact_func_is (ESExp *f,
-			gint argc,
-			ESExpResult **argv,
-			gpointer data)
+                 gint argc,
+                 ESExpResult **argv,
+                 gpointer data)
 {
 	return e_ews_implement_contact_contains (f, argc, argv, data, MATCH_IS);
 }
 
 static ESExpResult *
 contact_func_beginswith (ESExp *f,
-				gint argc,
-				ESExpResult **argv,
-				gpointer data)
+                         gint argc,
+                         ESExpResult **argv,
+                         gpointer data)
 {
 	return e_ews_implement_contact_contains (f, argc, argv, data, MATCH_BEGINS_WITH);
 }
 
 static ESExpResult *
 contact_func_endswith (ESExp *f,
-			gint argc,
-			ESExpResult **argv,
-			gpointer data)
+                       gint argc,
+                       ESExpResult **argv,
+                       gpointer data)
 {
 	return e_ews_implement_contact_contains (f, argc, argv, data, MATCH_ENDS_WITH);
 }
 
 static ESExpResult *
 func_or (ESExp *f,
-               gint argc,
-               ESExpTerm **argv,
-               gpointer data)
+         gint argc,
+         ESExpTerm **argv,
+         gpointer data)
 {
 	return e_ews_func_and_or_not (f, argc, argv, data, MATCH_OR);
 }
 
 static ESExpResult *
 func_and (ESExp *f,
-               gint argc,
-               ESExpTerm **argv,
-               gpointer data)
+          gint argc,
+          ESExpTerm **argv,
+          gpointer data)
 {
 	return e_ews_func_and_or_not (f, argc, argv, data, MATCH_AND);
 }
 
 static ESExpResult *
 func_not (ESExp *f,
-               gint argc,
-               ESExpTerm **argv,
-               gpointer data)
+          gint argc,
+          ESExpTerm **argv,
+          gpointer data)
 {
 	return e_ews_func_and_or_not (f, argc, argv, data, MATCH_NOT);
 }
@@ -1034,7 +1034,7 @@ static struct {
 	{ "is", contact_func_is, 0 },
 	{ "beginswith", contact_func_beginswith, 0 },
 	{ "endswith", contact_func_endswith, 0 },
-}; 
+};
 
 static struct {
 	const gchar *name;
@@ -1086,7 +1086,9 @@ static struct {
 };
 
 static void
-e_ews_convert_sexp_to_restriction (ESoapMessage *msg, const gchar *query, EwsFolderType type)
+e_ews_convert_sexp_to_restriction (ESoapMessage *msg,
+                                   const gchar *query,
+                                   EwsFolderType type)
 {
 	ESExp *sexp;
 	ESExpResult *r;
@@ -1137,7 +1139,8 @@ e_ews_convert_sexp_to_restriction (ESoapMessage *msg, const gchar *query, EwsFol
 }
 
 static gboolean
-e_ews_check_is_query (const gchar *query, EwsFolderType type)
+e_ews_check_is_query (const gchar *query,
+                      EwsFolderType type)
 {
 
 	if (!query)
@@ -1146,9 +1149,9 @@ e_ews_check_is_query (const gchar *query, EwsFolderType type)
 	if (type == EWS_FOLDER_TYPE_CONTACTS) {
 		if (!g_strcmp0 (query, "(contains \"x-evolution-any-field\" \"\")"))
 			return FALSE;
-		else 
+		else
 			return TRUE;
-	
+
 	} else if (type == EWS_FOLDER_TYPE_CALENDAR || type == EWS_FOLDER_TYPE_TASKS) {
 		if (!g_strcmp0 (query, "(contains? \"summary\"  \"\")"))
 			return FALSE;
@@ -1161,7 +1164,9 @@ e_ews_check_is_query (const gchar *query, EwsFolderType type)
 }
 
 void
-e_ews_query_to_restriction (ESoapMessage *msg, const gchar *query, EwsFolderType type)
+e_ews_query_to_restriction (ESoapMessage *msg,
+                            const gchar *query,
+                            EwsFolderType type)
 {
 	gboolean is_query;
 
